@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2015-2024, Vincenzo Arcidiacono;
+# Copyright 2015-2025, Vincenzo Arcidiacono;
 # Licensed under the EUPL (the 'Licence');
 # You may not use this work except in compliance with the Licence.
 # You may obtain a copy of the Licence at: http://ec.europa.eu/idabc/eupl
@@ -131,7 +131,7 @@ def _search_doc_in_func(dsp, node_id, where_succ=True, node_type='function',
                 else:
                     try:
                         sig = inspect.signature(fun)
-                    except ValueError:
+                    except (ValueError, TypeError):
                         return None, ''
                     var_positional = inspect.Parameter.VAR_POSITIONAL
                     for i, param in enumerate(sig.parameters.values()):
