@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2015-2024, Vincenzo Arcidiacono;
+# Copyright 2015-2025, Vincenzo Arcidiacono;
 # Licensed under the EUPL (the 'Licence');
 # You may not use this work except in compliance with the Licence.
 # You may obtain a copy of the Licence at: http://ec.europa.eu/idabc/eupl
@@ -1593,6 +1593,11 @@ class SiteMap(collections.OrderedDict):
         # noinspection PyArgumentList
         super(SiteMap, self).__setitem__(key, value, *args, **kwargs)
 
+    def __repr__(self):
+        return '%s({%s})' % (self.__class__.__name__, ", ".join(
+            f"{repr(k)}: {repr(v)}" for k, v in self.items()
+        ))
+
     def _repr_svg_(self):
         dot = list(self)[-1].dot()
         return dot.pipe(format='svg').decode(dot._encoding)
@@ -1716,18 +1721,23 @@ class SiteMap(collections.OrderedDict):
     def get_directory(self, directory):
         return directory or self.directory or tempfile.mkdtemp()
 
-    def basic_app(self, root_path, mute=True, blueprint_name=None, **kwargs):
-        import flask
-        root_path = osp.abspath(self.get_directory(root_path))
-        if blueprint_name is None:
-            app = flask.Flask(root_path, root_path=root_path, **kwargs)
-        else:
-            app = flask.Blueprint(
-                blueprint_name, root_path, root_path=root_path, **kwargs
-            )
+    def basic_app(self, root_path, mute=True, blueprint_name=None, app=None,
+                  **kwargs):
+        if app is None:
+            import flask
+            root_path = osp.abspath(self.get_directory(root_path))
+            if blueprint_name is None:
+                app = flask.Flask(root_path, root_path=root_path, **kwargs)
+            else:
+                app = flask.Blueprint(
+                    blueprint_name, root_path, root_path=root_path, **kwargs
+                )
         app.before_request(functools.partial(before_request, mute))
         return app
 
+    def init_app(self, app, **kwargs):
+        return self.app(app=app, **kwargs)
+
     def app(self, root_path=None, depth=-1, index=True, mute=True, viz_js=False,
             executor='async', blueprint_name=None, **kw):
         rendered = {}
