@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2015-2024, Vincenzo Arcidiacono;
+# Copyright 2015-2025, Vincenzo Arcidiacono;
 # Licensed under the EUPL (the 'Licence');
 # You may not use this work except in compliance with the Licence.
 # You may obtain a copy of the Licence at: http://ec.europa.eu/idabc/eupl
@@ -514,8 +514,9 @@ def stack_nested_keys(nested_dict, key=(), depth=-1):
     """
 
     if depth != 0 and hasattr(nested_dict, 'items'):
+        depth = depth - 1
         for k, v in nested_dict.items():
-            yield from stack_nested_keys(v, key=key + (k,), depth=depth - 1)
+            yield from stack_nested_keys(v, key=key + (k,), depth=depth)
     else:
         yield key, nested_dict
 
@@ -673,7 +674,7 @@ class SubDispatch(Base):
 
         >>> sol = o.workflow.nodes['Sub-dispatch']['solution']
         >>> sol
-        Solution([('a', 3), ('b', 4), ('c', 2)])
+        Solution({'a': 3, 'b': 4, 'c': 2})
         >>> sol == o['e']
         True
 
@@ -716,8 +717,10 @@ class SubDispatch(Base):
         :param wildcard:
             If True, when the data node is used as input and target in the
             ArciDispatch algorithm, the input value will be used as input for
-            the connected functions, but not as output.
-        :type wildcard: bool, optional
+            the connected functions, but not as output. If it is equal to 2, the
+            the data node that cannot be calculated are excluded by the wildcard
+            condition.
+        :type wildcard: bool, int, optional
 
         :param no_call:
             If True data node estimation function is not used.
@@ -748,7 +751,7 @@ class SubDispatch(Base):
             Function name.
         :type function_id: str, optional
         """
-
+        super(Base, self).__init__()
         self.dsp = dsp
         self.outputs = outputs
         self.wildcard = wildcard
@@ -865,9 +868,9 @@ class run_model:
         'max'
         >>> sol = dsp({'dsp_model': dsp_model, 'inputs': {'b': 1, 'a': 2}})
         >>> sol['outputs']
-        Solution([('a', 2), ('b', 1), ('c', 2)])
+        Solution({'a': 2, 'b': 1, 'c': 2})
         >>> sol.workflow.nodes['execute_dsp']['solution']
-        Solution([('a', 2), ('b', 1), ('c', 2)])
+        Solution({'a': 2, 'b': 1, 'c': 2})
 
     Moreover, it can be used also with all
     :func:`~schedula.utils.dsp.SubDispatcher` like objects::
@@ -877,7 +880,7 @@ class run_model:
         >>> sol['outputs']
         [2]
         >>> sol.workflow.nodes['execute_dsp']['solution']
-        Solution([('a', 2), ('b', 1), ('c', 2)])
+        Solution({'a': 2, 'b': 1, 'c': 2})
     """
 
     def __init__(self, func, *args, _init=None, **kwargs):
@@ -955,9 +958,9 @@ class MapDispatch(SubDispatch):
 
         >>> map_func = MapDispatch(dsp, recursive_inputs={'c': 'b'})
         >>> map_func([{'a': 1, 'b': 1}, {'a': 2}, {'a': 3}])
-        [Solution([('a', 1), ('b', 1), ('c', 2), ('d', 0)]),
-         Solution([('a', 2), ('b', 2), ('c', 4), ('d', 0)]),
-         Solution([('a', 3), ('b', 4), ('c', 7), ('d', -1)])]
+        [Solution({'a': 1, 'b': 1, 'c': 2, 'd': 0}),
+         Solution({'a': 2, 'b': 2, 'c': 4, 'd': 0}),
+         Solution({'a': 3, 'b': 4, 'c': 7, 'd': -1})]
     """
 
     def __init__(self, dsp, defaults=None, recursive_inputs=None,
@@ -1195,8 +1198,10 @@ class SubDispatchFunction(SubDispatch):
         :param wildcard:
             If True, when the data node is used as input and target in the
             ArciDispatch algorithm, the input value will be used as input for
-            the connected functions, but not as output.
-        :type wildcard: bool, optional
+            the connected functions, but not as output. If it is equal to 2, the
+            the data node that cannot be calculated are excluded by the wildcard
+            condition.
+        :type wildcard: bool, int, optional
 
         :param output_type:
             Type of function output:
@@ -1427,8 +1432,10 @@ class SubDispatchPipe(SubDispatchFunction):
         :param wildcard:
             If True, when the data node is used as input and target in the
             ArciDispatch algorithm, the input value will be used as input for
-            the connected functions, but not as output.
-        :type wildcard: bool, optional
+            the connected functions, but not as output. If it is equal to 2, the
+            the data node that cannot be calculated are excluded by the wildcard
+            condition.
+        :type wildcard: bool,int, optional
 
         :param output_type:
             Type of function output:
@@ -1470,7 +1477,8 @@ class SubDispatchPipe(SubDispatchFunction):
         self._sol.no_call = True
         self._sol._init_workflow()
         self._sol._run()
-        self._sol.no_call = False
+        for s in self._sol.sub_sol.values():
+            s.no_call = False
 
     def _set_pipe(self):
 
@@ -1690,8 +1698,8 @@ def add_function(dsp, inputs_kwargs=False, inputs_defaults=False, **kw):
         ... def g(e, i, *args, d=0):
         ...     return e + i + d
         >>> sol = dsp({'a': 1, 'b': 2, 'c': 3}); sol
-        Solution([('a', 1), ('b', 2), ('c', 3), ('h', 1), ('e', 1), ('i', 4),
-                  ('d', 5), ('l', 5)])
+        Solution({'a': 1, 'b': 2, 'c': 3, 'h': 1, 'e': 1, 'i': 4,
+                  'd': 5, 'l': 5})
     """
 
     def decorator(f):
@@ -1799,26 +1807,39 @@ class inf:
     __radd__ = __add__
     __rmul__ = __mul__
 
-    def __ge__(self, other):
-        other = isinstance(other, self.__class__) and tuple(other) or (0, other)
-        return tuple(self) >= other
-
-    def __gt__(self, other):
-        other = isinstance(other, self.__class__) and tuple(other) or (0, other)
-        return tuple(self) > other
-
     def __eq__(self, other):
-        other = isinstance(other, self.__class__) and tuple(other) or (0, other)
-        return tuple(self) == other
-
-    def __le__(self, other):
-        other = isinstance(other, self.__class__) and tuple(other) or (0, other)
-        return tuple(self) <= other
+        try:
+            return self._inf == other._inf and self._num == other._num
+        except AttributeError:
+            return self._inf == 0 and self._num == other
 
     def __lt__(self, other):
-        other = isinstance(other, self.__class__) and tuple(other) or (0, other)
-        return tuple(self) < other
+        try:
+            a = other._inf
+            return self._inf < a or (self._inf == a and self._num < other._num)
+        except AttributeError:
+            return self._inf < 0 or (self._inf == 0 and self._num < other)
+
+    def __le__(self, other):
+        try:
+            a = other._inf
+            return self._inf < a or (self._inf == a and self._num <= other._num)
+        except AttributeError:
+            return self._inf < 0 or (self._inf == 0 and self._num <= other)
+
+    def __gt__(self, other):
+        try:
+            a = other._inf
+            return self._inf > a or (self._inf == a and self._num > other._num)
+        except AttributeError:
+            return self._inf > 0 or (self._inf == 0 and self._num > other)
+
+    def __ge__(self, other):
+        try:
+            a = other._inf
+            return self._inf > a or (self._inf == a and self._num >= other._num)
+        except AttributeError:
+            return self._inf > 0 or (self._inf == 0 and self._num >= other)
 
     def __ne__(self, other):
-        other = isinstance(other, self.__class__) and tuple(other) or (0, other)
-        return tuple(self) != other
+        return not self == other
