@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2015-2024, Vincenzo Arcidiacono;
+# Copyright 2015-2025, Vincenzo Arcidiacono;
 # Licensed under the EUPL (the 'Licence');
 # You may not use this work except in compliance with the Licence.
 # You may obtain a copy of the Licence at: http://ec.europa.eu/idabc/eupl
@@ -20,7 +20,7 @@ from .dsp import stlp, get_nested_dicts, inf
 from .alg import get_full_pipe, _sort_sk_wait_in
 from .exc import DispatcherError, DispatcherAbort, SkipNode, ExecutorShutdown
 from .asy import async_thread, await_result, async_process, AsyncList, EXECUTORS
-from .utl import select_diff, dict_diff
+from .utl import select_diff
 
 log = logging.getLogger(__name__)
 
@@ -32,11 +32,17 @@ class Solution(Base, collections.OrderedDict):
     def __hash__(self):
         return id(self)
 
+    def __repr__(self):
+        return '%s({%s})' % (self.__class__.__name__, ", ".join(
+            f"{repr(k)}: {repr(v)}" for k, v in self.items()
+        ))
+
     def __init__(self, dsp=None, inputs=None, outputs=None, wildcard=False,
                  inputs_dist=None, no_call=False,
                  rm_unused_nds=False, wait_in=None, no_domain=False,
                  _empty=False, index=(-1,), full_name=(), verbose=False,
                  excluded_defaults=()):
+        super(Base, self).__init__()
         super(Solution, self).__init__()
         self.index = index
         self.rm_unused_nds = rm_unused_nds
@@ -57,7 +63,7 @@ class Solution(Base, collections.OrderedDict):
             self._set_inputs(inputs, inputs_dist, excluded_defaults)
 
             # Set wildcards.
-            self._set_wildcards(*((inputs, outputs) if wildcard else ()))
+            self._set_wildcards(wildcard, inputs, outputs)
 
             # Initialize workflow params.
             self._init_workflow()
@@ -76,7 +82,9 @@ class Solution(Base, collections.OrderedDict):
         excluded = set(excluded_defaults)
         if self.no_call:
             # Set initial values.
-            initial_values = dict_diff(self.dsp.default_values, excluded)
+            initial_values = select_diff(
+                self.dsp.default_values, excluded, 'value'
+            )
 
             if inputs is not None:  # Update initial values with input values.
                 initial_values.update(dict.fromkeys(inputs, NONE))
@@ -101,10 +109,18 @@ class Solution(Base, collections.OrderedDict):
 
         self.inputs, self.inputs_dist = initial_values, initial_distances
 
-    def _set_wildcards(self, inputs=None, outputs=None):
+    def _set_wildcards(self, wildcard, inputs=None, outputs=None):
         """
         Update wildcards set with the input data nodes that are also outputs.
 
+        :param wildcard:
+            If True, when the data node is used as input and target in the
+            ArciDispatch algorithm, the input value will be used as input for
+            the connected functions, but not as output. If it is equal to 2, the
+            the data node that cannot be calculated are excluded by the wildcard
+            condition.
+        :type wildcard: bool, int
+
         :param inputs:
             Input data nodes.
         :type inputs: list[str], iterable, optional
@@ -116,11 +132,17 @@ class Solution(Base, collections.OrderedDict):
 
         w = self._wildcards = set()  # Clean wildcards.
 
-        if outputs and inputs:
-            node, wi = self.nodes, self._wait_in.get  # Namespace shortcut.
+        if wildcard and outputs and inputs:
+            # Namespace shortcut.
+            node = self.nodes
+            wi = self._wait_in.get
+            pred = self._pred
 
             # Input data nodes that are in output_targets.
-            w_crd = {u: node[u] for u in inputs if u in outputs or wi(u, False)}
+            w_crd = {
+                u: node[u] for u in inputs
+                if (u in outputs and (wildcard != 2 or pred[u])) or wi(u, False)
+            }
 
             # Data nodes without the wildcard.
             w.update([k for k, v in w_crd.items() if v.get('wildcard', True)])
@@ -545,8 +567,9 @@ class Solution(Base, collections.OrderedDict):
                 value = args[0]
             else:
                 args = [v for v in args if v is not NONE]
-                value = self._evaluate_function(args, node_id, node_attr, attr,
-                                                **kw)
+                value = self._evaluate_function(
+                    args, node_id, node_attr, attr, **kw
+                )
             value = self._apply_filters(value, node_id, node_attr, attr, **kw)
             self._ended(attr, node_id)
 
@@ -630,8 +653,11 @@ class Solution(Base, collections.OrderedDict):
             succ_fun = []
 
             # namespace shortcuts for speed.
-            n, has, sub_sol = self.nodes, self.workflow.has_edge, self.sub_sol
-            index, add_succ_fun = self.index, succ_fun.append
+            n = self.nodes
+            has = self.workflow.has_edge
+            sub_sol = self.sub_sol
+            index = self.index
+            add_succ_fun = succ_fun.append
 
             for u in self._succ[node_id]:  # no_visited_in_sub_dsp.
                 node = n[u]
@@ -656,10 +682,11 @@ class Solution(Base, collections.OrderedDict):
         if 'filters' in node_attr:
             self._started(attr, node_id)
             attr['solution_filters'] = filters = [res]
+            append_result = filters.append
 
             # noinspection PyUnusedLocal
             def _callback(is_sol, sol):
-                filters.append(sol)
+                append_result(sol)
 
             res = async_process(
                 node_attr['filters'], res, stopper=stopper, executor=executor,
@@ -681,11 +708,14 @@ class Solution(Base, collections.OrderedDict):
 
     def _verbose(self, node_id, attr, end=False):
         if self.verbose:
-            if end:
-                msg = 'Done `%s` in {:.5f} sec.'.format(attr['duration'])
+            if isinstance(self.verbose, collections.abc.Callable):
+                self.verbose(self, node_id, attr, end)
             else:
-                msg = 'Start `%s`...'
-            log.info(msg % '/'.join(self.full_name + (node_id,)))
+                if end:
+                    msg = 'Done `%s` in {:.5f} sec.'.format(attr['duration'])
+                else:
+                    msg = 'Start `%s`...'
+                log.info(msg % '/'.join(self.full_name + (node_id,)))
 
     def _set_function_node_output(self, node_id, node_attr, no_call,
                                   next_nds=None, **kw):
