@@ -1,7 +1,7 @@
 # coding=utf-8
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2015-2024, Vincenzo Arcidiacono;
+# Copyright 2015-2025, Vincenzo Arcidiacono;
 # Licensed under the EUPL (the 'Licence');
 # You may not use this work except in compliance with the Licence.
 # You may obtain a copy of the Licence at: http://ec.europa.eu/idabc/eupl
@@ -68,30 +68,41 @@ class WebMap(SiteMap):
             root_path, mute=mute, blueprint_name=blueprint_name, **kwargs
         )
         app.before_request(self.before_request)
+        app.after_request(self.after_request)
         return app
 
-    def app(self, root_path=None, depth=-1, mute=False, blueprint_name=None,
-            **kwargs):
-        kwargs.pop('index', None)
-        app = self.basic_app(
-            root_path, mute=mute, blueprint_name=blueprint_name, **kwargs
-        )
-        app.after_request(self.after_request)
+    def api(self, depth=-1, debug=False):
+        from flask import Blueprint
+        bp = Blueprint('api', __name__)
         context = self.rules(depth=depth, index=False)
         opt = {'methods': self.methods}
         for i, ((node, extra), path) in enumerate(context.items()):
             view = functools.partial(self._func_handler, node.obj)
             if i:
-                app.add_url_rule('/%s' % path, f'api_{path}', view, **opt)
+                bp.add_url_rule('/%s' % path, f'root_{path}', view, **opt)
             else:
-                app.add_url_rule('/', 'api', view, **opt)
-                app.add_url_rule('/%s' % path, 'api', **opt)
+                bp.add_url_rule('/', 'root', view, **opt)
+                bp.add_url_rule('/%s' % path, 'root', **opt)
+        if debug:
+            bp.register_blueprint(self.sub_site())
+        return bp
 
+    def sub_site(self):
+        from flask import Blueprint
+        bp = Blueprint('subsite', __name__)
         opt = {'methods': self.subsite_methods}
-        app.add_url_rule('/subsite/<key>/', 'subsite', self._site_proxy, **opt)
-        app.add_url_rule('/subsite/<key>/<path:path>', 'subsite', **opt)
-        app.add_url_rule('/subsite/<key>/<string:path>', 'subsite', **opt)
+        bp.add_url_rule('/subsite/<key>/', 'root', self._site_proxy, **opt)
+        bp.add_url_rule('/subsite/<key>/<path:path>', 'root', **opt)
+        bp.add_url_rule('/subsite/<key>/<string:path>', 'root', **opt)
+        return bp
 
+    def app(self, root_path=None, depth=-1, mute=False, blueprint_name=None,
+            debug=False, **kwargs):
+        kwargs.pop('index', None)
+        app = self.basic_app(
+            root_path, mute=mute, blueprint_name=blueprint_name, **kwargs
+        )
+        app.register_blueprint(self.api(depth, debug))
         return app
 
     def render(self, *args, **kwargs):
@@ -102,7 +113,7 @@ class WebMap(SiteMap):
         from flask import url_for
         from string import ascii_lowercase, digits
         key = ''.join(random.choices(ascii_lowercase + digits, k=12))
-        upx = url_for('subsite', key=key)
+        upx = url_for('.subsite.root', key=key)
         site = func.plot(workflow=True, view=False).site(
             index=True, url_prefix=upx, blueprint_name='debug',
             idle_timeout=self.idle_timeout
@@ -118,13 +129,17 @@ class WebMap(SiteMap):
 
     @staticmethod
     def after_request(response):
+        if response.mimetype == 'text/html':
+            return response
         from flask import request, current_app, get_flashed_messages
         messages = get_flashed_messages(with_categories=True)
         if messages:
             headers = {}
             messages = current_app.json.dumps(messages).encode('utf8')
             if 'gzip' in request.headers.get('Accept-Encoding', '').lower():
-                messages = base64.b64encode(gzip.compress(messages))
+                messages = base64.b64encode(
+                    gzip.compress(messages)
+                ).decode("utf-8")
                 headers['X-Flash-Messages-length'] = len(messages)
                 headers['X-Flash-Messages-Encoding'] = 'gzip'
             headers['X-Flash-Messages'] = messages
