@@ -1197,6 +1197,7 @@ class TestDispatch(unittest.TestCase):
         dsp = self.dsp
         import logging
         logging.disable(False)
+        test_logger = logging.getLogger('test_logger')
         with self.assertLogs('schedula', level='INFO') as cm:
             o = dsp.dispatch({'a': 5, 'b': 6, 'f': 9}, verbose=True)
             self.assertEqual(
@@ -1212,6 +1213,31 @@ class TestDispatch(unittest.TestCase):
                 'INFO:schedula\.utils\.sol:Done `2 / \(d \+ 1\)` in \d+\.\d+ sec\.'
             ]
 
+            self.assertEqual(len(cm.output), len(cm.output))
+            for o, regex in zip(cm.output, res):
+                self.assertRegex(o, regex)
+        with self.assertLogs('test_logger', level='INFO') as cm:
+            def custom_verbose(sol, node_id, attr, end):
+                if end:
+                    msg = 'Done `%s` in {:.5f} sec.'.format(attr['duration'])
+                else:
+                    msg = 'Start `%s`...'
+                test_logger.info(msg % '/'.join(sol.full_name + (node_id,)))
+
+            o = dsp.dispatch({'a': 5, 'b': 6, 'f': 9}, verbose=custom_verbose)
+            self.assertEqual(
+                dict(o.items()),
+                {'a': 5, 'b': 6, 'c': 0, 'd': 0, 'e': 2, 'f': 9}
+            )
+            res = [
+                'INFO:test_logger:Start `log\(b - a\)`\.\.\.',
+                'INFO:test_logger:Done `log\(b - a\)` in \d+\.\d+ sec\.',
+                'INFO:test_logger:Start `min`\.\.\.',
+                'INFO:test_logger:Done `min` in \d+\.\d+ sec\.',
+                'INFO:test_logger:Start `2 / \(d \+ 1\)`\.\.\.',
+                'INFO:test_logger:Done `2 / \(d \+ 1\)` in \d+\.\d+ sec\.'
+            ]
+
             self.assertEqual(len(cm.output), len(cm.output))
             for o, regex in zip(cm.output, res):
                 self.assertRegex(o, regex)
@@ -1519,6 +1545,24 @@ class TestDispatch(unittest.TestCase):
         self.assertEqual(o.workflow.adj, w)
         self.assertEqual(set(o.workflow.nodes), r)
 
+        o = dsp.dispatch({'a': 5, 'b': 6}, ['a', 'b'], wildcard=2,
+                         shrink=True)
+        self.assertEqual(dict(o.items()), {
+            'a': 5, 'b': 1, 'c': 0, 'd': 0, 'e': 2
+        })
+        self.assertEqual(o.workflow.adj, {**w, **{
+            'x - 4': {},
+            'a': {
+                'log(b - a)': {'value': 5},
+                'min': {'value': 5},
+                'x - 4': {'value': 5}
+            }
+        }})
+        self.assertEqual(set(o.workflow.nodes), {
+            '2 / (d + 1)', 'a', 'b', 'c', 'd', 'e', 'log(b - a)', 'min',
+            sh.START, 'x - 4', 'x ^ y'
+        })
+
         dsp = self.dsp_wildcard_1
 
         o = dsp.dispatch({'a': 5, 'b': 6}, ['a', 'b'], wildcard=True)
